CockpitAtomicJsonFile class final

Constructors

CockpitAtomicJsonFile({required CockpitPermissionHardener permissionHardener, required CockpitDirectorySyncer directorySyncer, Random? random})

Properties

directorySyncer CockpitDirectorySyncer
final
hashCode int
The hash code for this object.
no setterinherited
permissionHardener CockpitPermissionHardener
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(String path, Object? value, {int? maximumBytes}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited