CockpitCaptureStrategyResolver class final
Constructors
- CockpitCaptureStrategyResolver({CockpitRemoteCaptureAdapterFactory remoteAdapterFactory = _defaultRemoteAdapterFactory, CockpitAdbCaptureAdapterFactory? adbAdapterFactory, CockpitSimctlCaptureAdapterFactory? simctlAdapterFactory, CockpitWdaCaptureAdapterFactory? wdaAdapterFactory, CockpitMacosCaptureAdapterFactory? macosAdapterFactory, CockpitWindowsCaptureAdapterFactory? windowsAdapterFactory, CockpitLinuxCaptureAdapterFactory? linuxAdapterFactory, CockpitBrowserHostAppIdResolver browserHostAppIdResolver = cockpitResolveBrowserHostAppId, CockpitHostPlatformResolver hostPlatformResolver = _defaultHostPlatformResolver})
-
const
Properties
- adbAdapterFactory → CockpitAdbCaptureAdapterFactory?
-
final
- browserHostAppIdResolver → CockpitBrowserHostAppIdResolver
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostPlatformResolver → CockpitHostPlatformResolver
-
final
- linuxAdapterFactory → CockpitLinuxCaptureAdapterFactory?
-
final
- macosAdapterFactory → CockpitMacosCaptureAdapterFactory?
-
final
- remoteAdapterFactory → CockpitRemoteCaptureAdapterFactory
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simctlAdapterFactory → CockpitAdbCaptureAdapterFactory?
-
final
- wdaAdapterFactory → CockpitWdaCaptureAdapterFactory?
-
final
- windowsAdapterFactory → CockpitWindowsCaptureAdapterFactory?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{required String platform, required CockpitRemoteSessionClient client, String? platformAppId, int? processId, CockpitRemoteSessionHandle? sessionHandle, String? deviceId, String? androidDeviceId, String? iosDeviceId, Uri? iosWdaBaseUri, CockpitCaptureTempFileFactory? artifactTempFileFactory}) → CockpitCaptureAdapter -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited