CockpitCreateProjectResult class final

Constructors

CockpitCreateProjectResult({required String projectDirectory, required CockpitWorkspaceCommand command, required bool success, required String stdout, required String stderr})
const

Properties

command CockpitWorkspaceCommand
final
hashCode int
The hash code for this object.
no setterinherited
projectDirectory String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
final
stdout String
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited