CockpitDaemonDiscovery class final

Constructors

CockpitDaemonDiscovery({String schemaVersion = cockpitDaemonDiscoverySchema, required String instanceId, required int processId, required String processStartIdentity, required Uri endpoint, required String bearerToken, required int apiMajor, required int apiMinor, required String engineVersion, required DateTime startedAt, CockpitAuthorizationMode authorizationMode = CockpitAuthorizationMode.restricted})
CockpitDaemonDiscovery.fromJson(Object? value)
factory

Properties

apiMajor int
final
apiMinor int
final
authorizationMode → CockpitAuthorizationMode
final
bearerToken String
final
endpoint Uri
final
engineVersion String
final
hashCode int
The hash code for this object.
no setterinherited
instanceId String
final
processId int
final
processStartIdentity String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
startedAt DateTime
final

Methods

identifiesSameInstance(CockpitDaemonDiscovery other) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited