CockpitDaemonDiscoveryStore class final

Constructors

CockpitDaemonDiscoveryStore({required CockpitHomePaths paths, required CockpitPermissionHardener permissionHardener, required CockpitDirectorySyncer directorySyncer})

Properties

directorySyncer CockpitDirectorySyncer
final
hashCode int
The hash code for this object.
no setterinherited
paths CockpitHomePaths
final
permissionHardener CockpitPermissionHardener
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteIfMatches(CockpitDaemonDiscovery discovery) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Future<CockpitDaemonDiscovery?>
toString() String
A string representation of this object.
inherited
write(CockpitDaemonDiscovery discovery) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited