CockpitHomePaths class final

Constructors

CockpitHomePaths(String home)

Properties

artifactsDirectory String
no setter
authorizationPolicy String
no setter
cliSessions String
no setter
daemonDiscovery String
no setter
daemonEnsureLock String
no setter
daemonLock String
no setter
daemonLog String
no setter
directories Iterable<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
home String
final
identityRegistry String
no setter
leaseRegistry String
no setter
leasesDirectory String
no setter
referencesRegistry String
no setter
registryDirectory String
no setter
rootsRegistry String
no setter
runsDirectory String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspacesRegistry String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited