CockpitHotRestartResult class final

Constructors

CockpitHotRestartResult({required CockpitAppHandle app, required CockpitDevelopmentSessionStatus status, String? appJsonPath})
const

Properties

app CockpitAppHandle
final
appJsonPath String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CockpitDevelopmentSessionStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited