CockpitLaunchTargetResult class final

Constructors

CockpitLaunchTargetResult({required CockpitTargetHandle target, String? targetJsonPath, CockpitAppHandle? app, String? recommendedNextStep, String? whatMatters})
const

Properties

app CockpitAppHandle?
final
hashCode int
The hash code for this object.
no setterinherited
recommendedNextStep String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target CockpitTargetHandle
final
targetJsonPath String?
final
whatMatters String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited