CockpitLspRequest class final

Constructors

CockpitLspRequest({required String workspaceRoot, required CockpitLspCommand command, String? path, int? line, int? column, String? query, List<String> allowedRoots = const <String>[], int maxResults = 20, int maxChars = 1600, Duration timeout = const Duration(seconds: 20)})
const

Properties

allowedRoots List<String>
final
column int?
final
command CockpitLspCommand
final
hashCode int
The hash code for this object.
no setterinherited
line int?
final
maxChars int
final
maxResults int
final
path String?
final
query String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final
workspaceRoot String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited