CockpitReadRemoteSnapshotRequest class final

Constructors

CockpitReadRemoteSnapshotRequest({Uri? baseUri, CockpitRemoteSessionHandle? sessionHandle, String? sessionHandlePath, String? androidDeviceId, String? iosDeviceId, CockpitInteractiveResultProfile resultProfile = const CockpitInteractiveResultProfile.standard(), CockpitSnapshotOptions? snapshotOptions, String? compareAgainstSnapshotRef, DateTime? deadline})
const

Properties

androidDeviceId String?
final
baseUri Uri?
final
compareAgainstSnapshotRef String?
final
deadline DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
iosDeviceId String?
final
resultProfile CockpitInteractiveResultProfile
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionHandle CockpitRemoteSessionHandle?
final
sessionHandlePath String?
final
snapshotOptions → CockpitSnapshotOptions?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited