CockpitRecordingStrategyResolver class final
Constructors
- CockpitRecordingStrategyResolver({CockpitRemoteRecordingAdapterFactory remoteAdapterFactory = _defaultRemoteAdapterFactory, CockpitAdbRecordingAdapterFactory adbAdapterFactory = _defaultAdbAdapterFactory, CockpitSimctlRecordingAdapterFactory simctlAdapterFactory = _defaultSimctlAdapterFactory, CockpitMacosRecordingAdapterFactory macosAdapterFactory = _defaultMacosAdapterFactory, CockpitWindowsRecordingAdapterFactory windowsAdapterFactory = _defaultWindowsAdapterFactory, CockpitLinuxRecordingAdapterFactory linuxAdapterFactory = _defaultLinuxAdapterFactory})
-
const
Properties
- adbAdapterFactory → CockpitAdbRecordingAdapterFactory
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linuxAdapterFactory → CockpitLinuxRecordingAdapterFactory
-
final
- macosAdapterFactory → CockpitMacosRecordingAdapterFactory
-
final
- remoteAdapterFactory → CockpitRemoteRecordingAdapterFactory
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simctlAdapterFactory → CockpitAdbRecordingAdapterFactory
-
final
- windowsAdapterFactory → CockpitWindowsRecordingAdapterFactory
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{required String platform, required CockpitRecordingRequest? recording, required CockpitRemoteSessionClient client, CockpitRemoteSessionHandle? sessionHandle, String? androidDeviceId, String? iosDeviceId, String? platformAppId, int? processId, bool preferActiveHostSession = false}) → CockpitRecordingAdapter? -
resolveDetailed(
{required String platform, required CockpitRecordingRequest? recording, required CockpitRemoteSessionClient client, CockpitRemoteSessionHandle? sessionHandle, String? androidDeviceId, String? iosDeviceId, String? platformAppId, int? processId, bool preferActiveHostSession = false}) → CockpitRecordingStrategyResolution? -
resolveDetailedForStop(
{required String platform, required CockpitRecordingRequest? recording, required CockpitRemoteSessionClient client, CockpitRemoteSessionHandle? sessionHandle, String? androidDeviceId, String? iosDeviceId, String? platformAppId, int? processId}) → Future< CockpitRecordingStrategyResolution?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited