CockpitSystemControlActionService class final

Constructors

CockpitSystemControlActionService({CockpitProcessManager? processManager, CockpitSystemControlRegistry registry = const CockpitSystemControlRegistry(), CockpitSystemControlService? systemControlService, CockpitSystemControlCaptureAdapterFactory? captureAdapterFactory, CockpitSystemControlRecordingAdapterFactory? recordingAdapterFactory, CockpitAndroidUiAutomation? androidUiAutomation, CockpitIosWdaRunner? iosWdaRunner, CockpitMacosAccessibilityTreeReader? macosAccessibilityTreeReader, CockpitMacosSystemDialogHandler? macosSystemDialogHandler, CockpitMacosApplicationProcessIdResolver? macosApplicationProcessIdResolver, CockpitWindowsNativeInputExecutor? windowsNativeInputExecutor, CockpitWindowsFocusStateReader? windowsFocusStateReader})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(CockpitSystemControlActionRequest request) Future<CockpitSystemControlActionResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited