CockpitGrepPackageUrisRequest class final
Constructors
-
CockpitGrepPackageUrisRequest({required String workspaceRoot, required List<
String> packageNames, required String query, List<String> allowedRoots = const <String>[], String searchDir = 'lib', bool useRegex = false, bool caseSensitive = false, int maxMatches = 60, int maxMatchesPerFile = 5, int maxLineLength = 240, Duration timeout = const Duration(seconds: 20)}) -
const
Properties
-
allowedRoots
→ List<
String> -
final
- caseSensitive → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLineLength → int
-
final
- maxMatches → int
-
final
- maxMatchesPerFile → int
-
final
-
packageNames
→ List<
String> -
final
- query → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchDir → String
-
final
- timeout → Duration
-
final
- useRegex → bool
-
final
- workspaceRoot → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited