CockpitLaunchAppRequest class final
Constructors
- CockpitLaunchAppRequest({required String projectDir, required String platform, required String deviceId, required int sessionPort, String? target, String? flavor, CockpitAppMode mode = CockpitAppMode.development, Duration launchTimeout = const Duration(seconds: 600), bool allowSessionPortFallback = true, String? appHandlePath, CockpitFlutterLaunchConfiguration launchConfiguration = CockpitFlutterLaunchConfiguration.empty})
-
const
Properties
- allowSessionPortFallback → bool
-
final
- appHandlePath → String?
-
final
- deviceId → String
-
final
- flavor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- launchConfiguration → CockpitFlutterLaunchConfiguration
-
final
- launchTimeout → Duration
-
final
- mode → CockpitAppMode
-
final
- platform → String
-
final
- projectDir → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionPort → int
-
final
- target → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited