CockpitStopRecordingRequest class final
Constructors
- CockpitStopRecordingRequest({String? appId, CockpitAppHandle? app, String? appHandlePath, Uri? baseUri, String? androidDeviceId, String? iosDeviceId})
-
const
Properties
- androidDeviceId → String?
-
final
- app → CockpitAppHandle?
-
final
- appHandlePath → String?
-
final
- appId → String?
-
final
- baseUri → Uri?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosDeviceId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited